@@ -807,21 +807,24 @@ extern char *getenv __P_ ((const char *env_var));
 # ifdef SYEAR
 #  undef  SYEAR
 # endif
-# define SYEAR(gc_d, gc_s)   (  ((gc_d)-(gc_s)+1) < DAY_MIN) \
-                                ? ((gc_d)-(gc_s)+(DAY_MAX+1)) \
-                                : ((gc_d)-(gc_s)+1)
+# define SYEAR(gc_d, gc_s)  ( (  ((gc_d)-(gc_s)+1) < DAY_MIN) \
+                                 ? ((gc_d)-(gc_s)+(DAY_MAX+1)) \
+                                 : ((gc_d)-(gc_s)+1) \
+                            )
 # ifdef SMONTH
 #  undef  SMONTH
 # endif
-# define SMONTH(gc_d, gc_s)  (  ((gc_d)+(gc_s)-1) > MONTH_MAX) \
-                                ? ((gc_d)+(gc_s)-(MONTH_MAX+1)) \
-                                : ((gc_d)+(gc_s)-1)
+# define SMONTH(gc_d, gc_s) ( (  ((gc_d)+(gc_s)-1) > MONTH_MAX) \
+                                 ? ((gc_d)+(gc_s)-(MONTH_MAX+1)) \
+                                 : ((gc_d)+(gc_s)-1) \
+                            )
 # ifdef SDAY
 #  undef  SDAY
 # endif
-# define SDAY(gc_d, gc_s)    (  ((gc_d)+(gc_s)-1) > DAY_MAX) \
-                                ? ((gc_d)+(gc_s)-(DAY_MAX+1)) \
-                                : ((gc_d)+(gc_s)-1)
+# define SDAY(gc_d, gc_s)   ( (  ((gc_d)+(gc_s)-1) > DAY_MAX) \
+                                 ? ((gc_d)+(gc_s)-(DAY_MAX+1)) \
+                                 : ((gc_d)+(gc_s)-1) \
+                            )
 
 
 
