@@ -1,7 +1,8 @@
+/*!
+*  \file hd-astro.c
+*  \brief Astronomical and support functions used by the eternal holiday list.
+*/
 /*
-*  hd-astro.c:  Astronomical and support functions used by the eternal holiday list.
-*
-*
 *  Copyright (c) 1994, 95, 96, 1997, 2000 Thomas Esken
 *  Copyright (c) 2010, 2011, 2013 Free Software Foundation, Inc.
 *
@@ -50,13 +51,9 @@ __END_DECLARATIONS
 /*
 *  Function implementations.
 */
-  static double
-meeus_equinox_solstice (mode, year, hour, min)
-     const double mode;
-     const int year;
-     int hour;
-     int min;
-/*
+static double
+meeus_equinox_solstice (const double mode, const int year, int hour, int min)
+/*!
    According to MODE (== 0.0|90.0|180.0|270.0), this function calculates the
      dates of equinoxes and solstices for the given YEAR (range: 0001...9999)
      and returns the properly converted Julian/Gregorian date and time fraction.
@@ -178,14 +175,8 @@ meeus_equinox_solstice (mode, year, hour, min)
 
 
 double
-equinox_solstice (longitude, day, month, year, hour, min)
-     const double longitude;
-     int *day;
-     int *month;
-     int *year;
-     const int hour;
-     const int min;
-/*
+equinox_solstice (const double longitude, int *day, int *month, int *year, const int hour, const int min)
+/*!
    Wrapper/driver function for selecting the proper function
      that calculates the date and time of the equinoxes/solstices
      ``most precise'' for the given YEAR.
@@ -207,13 +198,8 @@ equinox_solstice (longitude, day, month, year, hour, min)
 
 
 
-double delta_t (day, month, year, hour, min)
-     const int day;
-     const int month;
-     const int year;
-     const int hour;
-     const int min;
-/*
+double delta_t (const int day, const int month, const int year, const int hour, const int min)
+/*!
    Returns the approximate Delta_T in seconds plus fraction for the given
      Julian/Gregorian calendar date (range 00010101..99991231), which is the
      difference between Terrestrial Dynamical Time, TDT (formerly called
@@ -493,18 +479,9 @@ double delta_t (day, month, year, hour, min)
 
 
 double
-moonphase (phase_selector, find_eclipse, eclipse_type, lunation,
-	   day, month, year, hour, min)
-     const double phase_selector;
-     const Bool find_eclipse;
-     double *eclipse_type;
-     Ulint *lunation;
-     int *day;
-     int *month;
-     int *year;
-     int hour;
-     int min;
-/*
+moonphase (const double phase_selector, const Bool find_eclipse, double *eclipse_type, Ulint *lunation,
+	   int *day, int *month, int *year, int hour, int min)
+/*!
    According to PHASE_SELECTOR, this function calculates the requested Moon
      phase, which occurs on or later the given Julian/Gregorian date (range
      00010101...99991231).  This is the case if LUNATION is set to zero.
@@ -924,16 +901,8 @@ moonphase (phase_selector, find_eclipse, eclipse_type, lunation,
 
 
 double
-next_sun_longitude (longitude, step, mjd, day, month, year, hour, min)
-     double *longitude;
-     const double step;
-     const double mjd;
-     int *day;
-     int *month;
-     int *year;
-     const int hour;
-     const int min;
-/*
+next_sun_longitude (double *longitude, const double step, const double mjd, int *day, int *month, int *year, const int hour, const int min)
+/*!
    Calculates and returns the Julian/Gregorian date and time fraction
      (properly converted, and this number is also passed via the addresses
      of DAY, MONTH and YEAR), at which the true solar longitude degree has
@@ -983,15 +952,8 @@ next_sun_longitude (longitude, step, mjd, day, month, year, hour, min)
 
 
 double
-sun_longitude (longitude, day, month, year, hour, min, next_mode)
-     const double longitude;
-     int *day;
-     int *month;
-     int *year;
-     int hour;
-     int min;
-     const Bool next_mode;
-/*
+sun_longitude (const double longitude, int *day, int *month, int *year, int hour, int min, const Bool next_mode)
+/*!
    If LONGITUDE is set to SPECIAL_VALUE, this function calculates and returns
      the approximate apparent geocentric solar ecliptic longitude degree for
      the given Julian/Gregorian date (range 00010101...99991231), which occurs
@@ -1202,12 +1164,8 @@ LABEL_sel_start:
 
 
 void
-val2hours (val, hour, min, sec)
-     double val;
-     int *hour;
-     int *min;
-     double *sec;
-/*
+val2hours (double val, int *hour, int *min, double *sec)
+/*!
    Returns the day fraction which is given by VAL either converted to
      a rounded 24-hour time value HH:MM via the addresses of HOUR and MIN
      if SEC is NULL, or converted to a non-rounded 24-hour time value
@@ -1264,12 +1222,8 @@ val2hours (val, hour, min, sec)
 
 
 void
-val2degrees (val, degree, min, sec)
-     double val;
-     int *degree;
-     int *min;
-     double *sec;
-/*
+val2degrees (double val, int *degree, int *min, double *sec)
+/*!
    Returns VAL either converted to a rounded 360-degree value DDDdMM'
      via the addresses of DEGREE and MIN if SEC is NULL, or converted
      to a non-rounded 360-degree value DDDdMM'SS.FRACTION via the
@@ -1325,9 +1279,8 @@ val2degrees (val, degree, min, sec)
 
 
 double
-my_cot (x)
-     double x;
-/*
+my_cot (double x)
+/*!
    Computes the "cotangent" of a given X by using the formula:
 
      cotangent X := 1 / tangent X
@@ -1348,9 +1301,8 @@ my_cot (x)
 
 
 double
-my_acot (x)
-     double x;
-/*
+my_acot (double x)
+/*!
    Computes the "arc cotangent" of a given X by using the formulae:
 
      arc cotangent X := arc tangent 1 / X
@@ -1377,10 +1329,8 @@ my_acot (x)
 
 
 double
-my_atan2 (y, x)
-     double y;
-     double x;
-/*
+my_atan2 (double y, double x)
+/*!
    Computes the "arc tangent Y/X" selecting the correct quadrant,
      i.e. returns the angle between 0 and 2 Pi whose tangent is Y/X.
 */
@@ -1398,12 +1348,11 @@ my_atan2 (y, x)
 }
 
 
-
 #if !HAVE_LIBM
+#error is there any system that does not have libm
 double
-my_floor (x)
-     double x;
-/*
+my_floor (double x)
+/*!
    Returns the largest integer value not greater than X.
 */
 {
@@ -1434,9 +1383,8 @@ my_floor (x)
 
 
 double
-my_ceil (x)
-     double x;
-/*
+my_ceil (double x)
+/*!
    Returns the smallest integer value not less than X.
 */
 {
@@ -1467,9 +1415,8 @@ my_ceil (x)
 
 
 double
-my_sqrt (x)
-     double x;
-/*
+my_sqrt (double x)
+/*!
    Computes the "square root" of a given X by using Newton's iteration formula:
 
      sqrt X :=  X    = X - (f(X ) / f'(X )) , n=0,1,2,... , abs((f(X) * f''(X)) / (f'(X))^2) < 1
@@ -1505,9 +1452,8 @@ my_sqrt (x)
 
 
 double
-my_log (x)
-     double x;
-/*
+my_log (double x)
+/*!
    Computes the "logarithm base e" (logarithmus naturalis, ln) of a given X
      by using a series and the fact, that log  X^2 == 2 log  X:
                                              e             e
@@ -1582,9 +1528,8 @@ my_log (x)
 
 
 double
-my_log10 (x)
-     double x;
-/*
+my_log10 (double x)
+/*!
    Computes the "logarithm base 10" of a given X by using the formula:
 
      log   X := log  X / log  10
@@ -1601,9 +1546,8 @@ my_log10 (x)
 
 
 double
-my_sin (x)
-     double x;
-/*
+my_sin (double x)
+/*!
    Computes the "sine" of a given X by using the series:
 
      sine X :=   X
@@ -1675,9 +1619,8 @@ my_sin (x)
 
 
 double
-my_cos (x)
-     double x;
-/*
+my_cos (double x)
+/*!
    Computes the "cosine" of a given X by using the formula:
 
      cosine X := sine (X + Pi / 2)
@@ -1689,9 +1632,8 @@ my_cos (x)
 
 
 double
-my_tan (x)
-     double x;
-/*
+my_tan (double x)
+/*!
    Computes the "tangent" of a given X by using the formula:
 
      tangent X := sine X / cosine X
@@ -1710,9 +1652,8 @@ my_tan (x)
 
 
 double
-my_asin (x)
-     double x;
-/*
+my_asin (double x)
+/*!
    Computes the "arc sine" of a given X by using the formula:
 
      arc sine X := Pi / 2 - arc tangent (square root (1 - X * X) / X)
@@ -1750,9 +1691,8 @@ my_asin (x)
 
 
 double
-my_acos (x)
-     double x;
-/*
+my_acos (double x)
+/*!
    Computes the "arc cosine" of a given X by using the formula:
 
      arc cosine := Pi / 2 - arc sine X
@@ -1768,9 +1708,8 @@ my_acos (x)
 
 
 double
-my_atan (x)
-     double x;
-/*
+my_atan (double x)
+/*!
    Computes the "arc tangent" of a given X by using the formula:
 
      arc tangent X := arc tangent c + arc tangent ((X - c) / (1 + X * c))
