@@ -1,10 +1,11 @@
 #ifndef __HD_DATA2_H
 # define __HD_DATA2_H
-/*
-*  hd-data2.h:  All other A-C countries data which is composed into the
+/*!
+*  \file hd-data2.h
+*  \brief All other A-C countries data which is composed into the
 *               eternal holiday list header file.
-*
-*
+*/
+/*
 *  Copyright (c) 1994, 95, 96, 1997, 2000 Thomas Esken
 *  Copyright (c) 2010, 2011, 2013 Free Software Foundation, Inc.
 *
@@ -135,6 +136,60 @@ extern void
 		int easter,
 		const int year,
 		int *hd_elems, const int fday, const int count));
+extern void
+  at_vo_hdy __P_ ((Bool * init_data,
+		const Bool detected,
+		int easter,
+		const int year,
+		int *hd_elems, const int fday, const int count));
+extern void
+  at_ti_hdy __P_ ((Bool * init_data,
+		const Bool detected,
+		int easter,
+		const int year,
+		int *hd_elems, const int fday, const int count));
+extern void
+  at_sa_hdy __P_ ((Bool * init_data,
+		const Bool detected,
+		int easter,
+		const int year,
+		int *hd_elems, const int fday, const int count));
+extern void
+  at_ka_hdy __P_ ((Bool * init_data,
+		const Bool detected,
+		int easter,
+		const int year,
+		int *hd_elems, const int fday, const int count));
+extern void
+  at_st_hdy __P_ ((Bool * init_data,
+		const Bool detected,
+		int easter,
+		const int year,
+		int *hd_elems, const int fday, const int count));
+extern void
+  at_oo_hdy __P_ ((Bool * init_data,
+		const Bool detected,
+		int easter,
+		const int year,
+		int *hd_elems, const int fday, const int count));
+extern void
+  at_no_hdy __P_ ((Bool * init_data,
+		const Bool detected,
+		int easter,
+		const int year,
+		int *hd_elems, const int fday, const int count));
+extern void
+  at_bu_hdy __P_ ((Bool * init_data,
+		const Bool detected,
+		int easter,
+		const int year,
+		int *hd_elems, const int fday, const int count));
+extern void
+  at_wi_hdy __P_ ((Bool * init_data,
+		const Bool detected,
+		int easter,
+		const int year,
+		int *hd_elems, const int fday, const int count));
 extern void
   au_ct_hdy __P_ ((Bool * init_data,
 		   const Bool detected,
