@@ -553,7 +553,7 @@
 #  define HD_NEVADA_DAY                         447
 #  define HD_NEW_REGIME_ANNIVERSARY             448
 #  define HD_NOBEL_DAY                          449
-#  define HD_NOI_DAY                            450
+#  define HD_MOI_DAY                            450
 #  define HD_OAU_DAY                            451
 #  define HD_OCTOBER_HOLIDAY                    452
 #  define HD_OIL_INDUSTRY_DAY                   453
@@ -655,6 +655,12 @@
 #  define HD_W_TUBMANS_BIRTHDAY                 549
 #  define HD_YAP_DAY                            550
 #  define HD_DAY_OF_CZECH_STATEHOOD             551
+#  define HD_DAY_OF_THE_REFERENDUM              552
+#  define HD_SAINT_FLORIAN                      553
+#  define HD_RUPERT_OF_SALZBURG                 554
+#  define HD_SAINT_LEOPOLD_III                  555
+#  define HD_DAY_OF_REMEMBRANCE_AND_RECOGNITION 556
+#  define HD_ST_BRIGIDS_DAY                     557
 # endif	/* !HD_TOP20CC */
 
 
@@ -668,7 +674,7 @@
 typedef struct country_code_type
 {
   /*
-     The ISO-3166 2-characters country code identifer,
+     The ISO-3166 2-characters country code identifier,
      plus an optionally trailing territory text `_TT'.
    */
   char *cc_id;
@@ -677,7 +683,7 @@ typedef struct country_code_type
   char *cc_info;
 
   /* The country code specific holiday handling function. */
-  void (*Cc_hdy_handler) ();
+  void (*Cc_hdy_handler) (Bool *, const Bool, int, const int, int *, const int, const int);
 }
 Cc_struct;
 
