@@ -1,8 +1,9 @@
-/*
-*  rc-check.c:  Checks if a line (of a resource file)
+/*!
+*  \file rc-check.c
+*  \brief Checks if a line (of a resource file)
 *               must be inserted into `rc_elems_table[]'.
-*
-*
+*/
+/*
 *  Copyright (c) 1994, 95, 96, 1997, 2000 Thomas Esken
 *  Copyright (c) 2010, 2011, 2013 Free Software Foundation, Inc.
 *
@@ -66,10 +67,10 @@ __END_DECLARATIONS
 /*
 *  static variables definitions.
 */
-/* Textual weekday name is found and must be respected. */
+/*! Textual weekday name is found and must be respected. */
 static Bool is_weekday_mode = FALSE;
 
-/* No explicit month command is given in the command line. */
+/*! No explicit month command is given in the command line. */
 static Bool changed_month = FALSE;
 
 
@@ -78,17 +79,9 @@ static Bool changed_month = FALSE;
 *  Function implementations.
 */
 void
-rc_check (line_buffer, filename, line_number, line_length, rc_elems, day, ed,
-	  wd)
-     char *line_buffer;
-     const char *filename;
-     const long line_number;
-     const int line_length;
-     int *rc_elems;
-     const int day;
-     const int ed;
-     const int wd;
-/*
+rc_check (char *line_buffer, const char *filename, const long line_number, const int line_length, int *rc_elems, const int day, const int ed,
+	  const int wd)
+/*!
    Checks whether a single line of a resource file resp.,
      eternal holiday must be displayed.
 */
@@ -1431,7 +1424,7 @@ rc_check (line_buffer, filename, line_number, line_length, rc_elems, day, ed,
 				  else
 				    {
 				      /*
-				         Check whether this single event also occurs in in next year.
+				         Check whether this single event also occurs in next year.
 				       */
 				      j =
 					day_of_year (i, fiscal_month - 1,
@@ -1725,12 +1718,8 @@ rc_check (line_buffer, filename, line_number, line_length, rc_elems, day, ed,
 
 
 static Bool
-date_matches_period (print_twice, day, ed, wd)
-     int *print_twice;
-     int day;
-     int ed;
-     const int wd;
-/*
+date_matches_period (int *print_twice, int day, int ed, const int wd)
+/*!
    Checks if a given date (module global variables `d' for the day, `m' for
      the month and `y' for the year) matches a given period, which starts at
      absolute day of year `day' and ends at absolute day of year `ed' (the
@@ -2323,9 +2312,8 @@ date_matches_period (print_twice, day, ed, wd)
 
 
 static int
-get_number (string)
-     char **string;
-/*
+get_number (char **string)
+/*!
    Returns the absolute value of a "repeat for N days since..." field or
      "for each N'th day since..." field using the global `s6' text buffer.
 */
