@@ -1,13 +1,15 @@
-/*
-*  tcal.c:  Start `gcal' with date set ONE day ahead (default mode,
-*             like the `--shift=1' long-style option is passed to it).
-*             Useful if you call this program in `~/.profile' and you
-*             want to see all fixed dates related to tomorrow + 1 day
-*             (advanced  -ct  respectively  --period-of-fixed-dates=t  option).
-*             Works *only* for Gregorian years!
+/*!
+*  \file tcal.c
+*  \brief Start `gcal' with date set ONE day ahead
 *
+*  (default mode, like the `--shift=1' long-style option is passed to it).
+*  Useful if you call this program in `~/.profile' and you want to see all
+*  fixed dates related to tomorrow + 1 day (advanced  -ct respectively
+*  --period-of-fixed-dates=t  option).  Works *only* for Gregorian years!
+*/
+/*
 *  Copyright (c) 2000, 2001, 2002, 2003, 2004, 2005, 2006, 2007, 2008,
-*  2009, 2010, 2011 Free Software Foundation, Inc.
+*  2009, 2010, 2011, 2013, 2014 Free Software Foundation, Inc.
 *  Copyright (c) 1995, 96, 1997, 2000 Thomas Esken
 *
 *  This software doesn't claim completeness, correctness or usability.
@@ -122,18 +124,18 @@ __END_DECLARATIONS
 /*
 *  static variables definitions.
 */
-/*
+/*!
    Number of days in months.
 */
 static const int dvec[] = { 31, 28, 31, 30, 31, 30, 31, 31, 30, 31, 30, 31 };
 
-/*
+/*!
    Number of past days of month.
 */
 static const int mvec[] =
   { 0, 31, 59, 90, 120, 151, 181, 212, 243, 273, 304, 334 };
 
-/*
+/*!
    The Gregorian Reformation dates table is an unterminated vector
      of `Greg_struct'.
 */
@@ -145,30 +147,30 @@ static Greg_struct greg_reform_date[] = {
   {1752, 9, 3, 13}
 };
 
-/* Points to the used Gregorian Reformation date. */
+/*! Points to the used Gregorian Reformation date. */
 static Greg_struct *greg = greg_reform_date;
 
 #ifdef DJG
-/* Set to SHRT_MAX for checking the maximum table range. */
+/*! Set to SHRT_MAX for checking the maximum table range. */
 static Usint testval = (Usint) 0;
 #else
-/* Set to INT_MAX for checking the maximum table range. */
+/*! Set to INT_MAX for checking the maximum table range. */
 static Uint testval = (Uint) 0;
 #endif
 
-/* Actual length of all strings. */
+/*! Actual length of all strings. */
 static Uint maxlen_max = MAXLEN_MAX;
 
-/* The name of this executable. */
+/*! The name of this executable. */
 static char *prgr_name = (char *) NULL;
 
-/* Text of `--help' option name. */
+/*! Text of `--help' option name. */
 static char *help_option_name = "help";
 
-/* Text of `--version' option name. */
+/*! Text of `--version' option name. */
 static char *version_option_name = "version";
 
-/* Text of `--shift' option name. */
+/*! Text of `--shift' option name. */
 static char *shift_option_name = "shift";
 
 
@@ -177,11 +179,8 @@ static char *shift_option_name = "shift";
 *  Function implementations.
 */
 static void
-usage_msg (fp, prgr_name, exit_status)
-     FILE *fp;
-     const char *prgr_name;
-     int exit_status;
-/*
+usage_msg (FILE *fp, const char *prgr_name, int exit_status)
+/*!
    Writes the program "usage" text to file `fp' and
      terminates the program with `exit_status'.
 */
@@ -203,11 +202,8 @@ usage_msg (fp, prgr_name, exit_status)
 
 
 static void
-version_msg (fp, prgr_name, exit_status)
-     FILE *fp;
-     const char *prgr_name;
-     int exit_status;
-/*
+version_msg (FILE *fp, const char *prgr_name, int exit_status)
+/*!
    Writes the program "version" text to file `fp' and
      terminates the program with `exit_status'.
 */
@@ -229,15 +225,9 @@ version_msg (fp, prgr_name, exit_status)
 
 
 static VOID_PTR
-my_malloc (amount, exit_status, module_name, module_line, var_name,
-	   var_contents)
-     const int amount;
-     const int exit_status;
-     const char *module_name;
-     const long module_line;
-     const char *var_name;
-     const int var_contents;
-/*
+my_malloc (const int amount, const int exit_status, const char *module_name, const long module_line, const char *var_name,
+	   const int var_contents)
+/*!
    Allocate AMOUNT bytes of memory dynamically, with error checking.
      Calls `my_error()' and terminates the program if any errors occur.
      AMOUNT is limited to `int' range instead of `size_t' range;
@@ -266,16 +256,9 @@ my_malloc (amount, exit_status, module_name, module_line, var_name,
 
 
 static VOID_PTR
-my_realloc (ptr_memblock, amount, exit_status, module_name, module_line,
-	    var_name, var_contents)
-     VOID_PTR ptr_memblock;
-     const int amount;
-     const int exit_status;
-     const char *module_name;
-     const long module_line;
-     const char *var_name;
-     const int var_contents;
-/*
+my_realloc (VOID_PTR ptr_memblock, const int amount, const int exit_status, const char *module_name, const long module_line,
+	    const char *var_name, const int var_contents)
+/*!
    Change the size of an allocated block of memory PTR_MEMBLOCK to AMOUNT
      bytes, with error checking.  Calls `my_error()' and terminates the program
      if any errors occur.  AMOUNT is limited to `int' range instead of `size_t'
@@ -306,13 +289,8 @@ my_realloc (ptr_memblock, amount, exit_status, module_name, module_line,
 
 
 static void
-my_error (exit_status, module_name, module_line, var_name, var_contents)
-     const int exit_status;
-     const char *module_name;
-     const long module_line;
-     const char *var_name;
-     const int var_contents;
-/*
+my_error (const int exit_status, const char *module_name, const long module_line, const char *var_name, const int var_contents)
+/*!
    Displays a specific error message on STDERR channel
      and terminates the program with status `exit_status'.
 */
@@ -328,7 +306,7 @@ my_error (exit_status, module_name, module_line, var_name, var_contents)
       fprintf (stderr,
 	       _
 	       ("`%s' line %ld: (`%s') invalid value for table size `sizeof %s>%d'"),
-	       module_name, module_line, _("Internal"), var_name,
+	       module_name, module_line, _("internal"), var_name,
 	       var_contents);
       break;
     case EXIT_FATAL:
@@ -336,7 +314,7 @@ my_error (exit_status, module_name, module_line, var_name, var_contents)
       break;
     default:
       fprintf (stderr, _("`%s' line %ld: (`%s') unmanaged error (%d)"),
-	       module_name, module_line, _("Internal"), exit_status);
+	       module_name, module_line, _("internal"), exit_status);
     }
   S_NEWLINE (stderr);
   exit (exit_status);
@@ -346,9 +324,8 @@ my_error (exit_status, module_name, module_line, var_name, var_contents)
 
 #if HAVE_SIGNAL && (defined(SIGINT) || defined(SIGTERM) || defined(SIGHUP))
 static RETSIGTYPE
-handle_signal (the_signal)
-     int the_signal;
-/*
+handle_signal (int the_signal)
+/*!
    Signal handler function which displays the numeric ID of the
      received signal on STDERR channel and terminates the program
      with ERR_TERMINATION_BY_SIGNAL exit status.
@@ -365,11 +342,8 @@ handle_signal (the_signal)
 
 #if !HAVE_STRNCASECMP
 static int
-my_strncasecmp (s1, s2, len)
-     const char *s1;
-     const char *s2;
-     int len;
-/*
+my_strncasecmp (const char *s1, const char *s2, int len)
+/*!
    Same as the ANSI C `strncmp()' function, but case insensitive.
 */
 {
@@ -399,9 +373,8 @@ my_strncasecmp (s1, s2, len)
 
 
 static int
-days_of_february (year)
-     const int year;
-/*
+days_of_february (const int year)
+/*!
    Computes the number of days in February --- respecting
      the Gregorian Reformation period --- and returns them.
 */
@@ -428,12 +401,8 @@ days_of_february (year)
 
 
 static Bool
-doy2date (doy, is_leap_year, day, month)
-     int doy;
-     const int is_leap_year;
-     int *day;
-     int *month;
-/*
+doy2date (int doy, const int is_leap_year, int *day, int *month)
+/*!
    Converts a given number of days of a year to a standard date
      (returned in &day and &month) and returns:
        TRUE in case the `day_of_year' number is valid;
@@ -469,11 +438,8 @@ doy2date (doy, is_leap_year, day, month)
 
 
 static Ulint
-date2num (day, month, year)
-     const int day;
-     const int month;
-     const int year;
-/*
+date2num (const int day, const int month, const int year)
+/*!
    Computes the absolute number of days of the given date since
      00010101(==YYYYMMDD) respecting the missing period of the
      Gregorian Reformation.
@@ -506,12 +472,8 @@ date2num (day, month, year)
 
 
 static void
-num2date (mjd, day, month, year)
-     Ulint mjd;
-     int *day;
-     int *month;
-     int *year;
-/*
+num2date (Ulint mjd, int *day, int *month, int *year)
+/*!
    Converts a delivered absolute number of days `mjd' to a standard
      date (since 00010101(==YYYYMMDD), returned in &day, &month and &year)
      respecting the missing period of the Gregorian Reformation.
@@ -569,11 +531,8 @@ num2date (mjd, day, month, year)
 
 
 static void
-get_actual_date (day, month, year)
-     int *day;
-     int *month;
-     int *year;
-/*
+get_actual_date (int *day, int *month, int *year)
+/*!
    Gets the actual date from the system.
 */
 {
@@ -593,10 +552,8 @@ get_actual_date (day, month, year)
 
 
 int
-main (argc, argv)
-     int argc;
-     char *argv[];
-/*
+main (int argc, char *argv[])
+/*!
    Starts Gcal with date set one day ahead (default mode, like the `--shift=1'
      long-style option is passed to it) and all other arguments which are given
      in the command line.  The program first tries to use the `gcal' executable
