@@ -1,9 +1,10 @@
+/*!
+*  \file utils.c
+*  \brief Pool of common functions.
+*/
 /*
-*  utils.c:  Pool of common functions.
-*
-*
 *  Copyright (c) 1994, 95, 96, 1997, 2000, 2011 Thomas Esken
-*  Copyright (c) 2010, 2011, 2013 Free Software Foundation, Inc.
+*  Copyright (c) 2010, 2011, 2013, 2014 Free Software Foundation, Inc.
 *
 *  This software doesn't claim completeness, correctness or usability.
 *  On principle I will not be liable for ANY damages or losses (implicit
@@ -81,15 +82,9 @@ __END_DECLARATIONS
 *  Function implementations.
 */
   VOID_PTR
-my_malloc (amount, exit_status, module_name, module_line, var_name,
-	   var_contents)
-     const int amount;
-     const int exit_status;
-     const char *module_name;
-     const long module_line;
-     const char *var_name;
-     const int var_contents;
-/*
+my_malloc (const int amount, const int exit_status, const char *module_name, const long module_line, const char *var_name,
+	   const int var_contents)
+/*!
    Allocates AMOUNT bytes of memory dynamically, with error checking.
      Calls `my_error()' and terminates the program if any errors occur.
      AMOUNT is limited to `int' range instead of `size_t' range;
@@ -118,16 +113,9 @@ my_malloc (amount, exit_status, module_name, module_line, var_name,
 
 
 VOID_PTR
-my_realloc (ptr_memblock, amount, exit_status, module_name, module_line,
-	    var_name, var_contents)
-     VOID_PTR ptr_memblock;
-     const int amount;
-     const int exit_status;
-     const char *module_name;
-     const long module_line;
-     const char *var_name;
-     const int var_contents;
-/*
+my_realloc (VOID_PTR ptr_memblock, const int amount, const int exit_status, const char *module_name, const long module_line,
+	    const char *var_name, const int var_contents)
+/*!
    Changes the size of an allocated block of memory PTR_MEMBLOCK to AMOUNT
      bytes, with error checking.  Calls `my_error()' and terminates the program
      if any errors occur.  AMOUNT is limited to `int' range instead of `size_t'
@@ -158,11 +146,8 @@ my_realloc (ptr_memblock, amount, exit_status, module_name, module_line,
 
 
 void
-allocate_all_strings (amount, module_name, module_line)
-     const int amount;
-     const char *module_name;
-     const long module_line;
-/*
+allocate_all_strings (const int amount, const char *module_name, const long module_line)
+/*!
    Initially allocates AMOUNT bytes of memory dynamically for all string
      vectors used, with error checking.  Calls `my_error()' indirectly and
      terminates the program if any errors occur.  AMOUNT is limited to `int'
@@ -208,12 +193,8 @@ allocate_all_strings (amount, module_name, module_line)
 
 
 void
-resize_all_strings (amount, with_line_buffer, module_name, module_line)
-     const int amount;
-     const Bool with_line_buffer;
-     const char *module_name;
-     const long module_line;
-/*
+resize_all_strings (const int amount, const Bool with_line_buffer, const char *module_name, const long module_line)
+/*!
    Changes the size of all string vectors used to AMOUNT bytes, with error
      checking.  Calls `my_error()' indirectly and terminates the program
      if any errors occur. AMOUNT is limited to `int' range instead of `size_t'
@@ -257,13 +238,8 @@ resize_all_strings (amount, with_line_buffer, module_name, module_line)
 
 
 void
-my_error (exit_status, module_name, module_line, var_name, var_contents)
-     const int exit_status;
-     const char *module_name;
-     const long module_line;
-     const char *var_name;
-     const int var_contents;
-/*
+my_error (const int exit_status, const char *module_name, const long module_line, const char *var_name, const int var_contents)
+/*!
    Displays a specific error message on STDERR channel
      and terminates the program with status `exit_status'.
 */
@@ -381,7 +357,7 @@ my_error (exit_status, module_name, module_line, var_name, var_contents)
 #endif	/* USE_RC */
     default:
       fprintf (stderr, _("`%s' line %ld: (`%s') unmanaged error (%d)"),
-	       module_name, module_line, _("Internal"), exit_status);
+	       module_name, module_line, _("internal"), exit_status);
     }
   S_NEWLINE (stderr);
   my_exit (exit_status);
@@ -391,9 +367,8 @@ my_error (exit_status, module_name, module_line, var_name, var_contents)
 
 #if HAVE_SIGNAL && (defined(SIGINT) || defined(SIGTERM) || defined(SIGHUP))
 RETSIGTYPE
-handle_signal (the_signal)
-     int the_signal;
-/*
+handle_signal (int the_signal)
+/*!
    Signal handler function which displays the numeric ID of the
      received signal on STDERR channel and terminates the program
      with ERR_TERMINATION_BY_SIGNAL exit status.
@@ -409,9 +384,8 @@ handle_signal (the_signal)
 
 
 void
-my_exit (exit_status)
-     const int exit_status;
-/*
+my_exit (const int exit_status)
+/*!
    Tries to erase all temporary files before without error checking
      and quits the program by calling the systems `exit()' function.
 */
@@ -438,9 +412,8 @@ my_exit (exit_status)
 
 
 int
-my_atoi (string)
-     const char *string;
-/*
+my_atoi (const char *string)
+/*!
    Converts given `string' to a positiv integer value
      skipping leading zeroes and returns values in
      range 0...YEAR_MAX only (invalid values are set to 0).
@@ -457,9 +430,8 @@ my_atoi (string)
 
 
 int
-my_system (command)
-     const char *command;
-/*
+my_system (const char *command)
+/*!
    Wrapper for the system() function.
 */
 {
@@ -474,10 +446,8 @@ my_system (command)
 
 #if !HAVE_STRSTR
 char *
-my_strstr (text, pattern)
-     const char *text;
-     const char *pattern;
-/*
+my_strstr (const char *text, const char *pattern)
+/*!
    Search the `pattern' needle in haystack `text'   =8^)
      (emulates the ANSI C strstr() function; not very well optimized).
 */
@@ -508,10 +478,8 @@ my_strstr (text, pattern)
 
 #if !HAVE_STRCSPN
 int
-my_strcspn (s1, s2)
-     const char *s1;
-     const char *s2;
-/*
+my_strcspn (const char *s1, const char *s2)
+/*!
    Find length of initial segment of `s1' consisting entirely
    of characters not from `s2' (emulates the ANSI C strcspn() function).
 */
@@ -537,10 +505,8 @@ my_strcspn (s1, s2)
 
 #if !HAVE_STRCASECMP
 int
-my_strcasecmp (s1, s2)
-     const char *s1;
-     const char *s2;
-/*
+my_strcasecmp (const char *s1, const char *s2)
+/*!
    Same as the ANSI C `strcmp()' function, but case insensitive.
 */
 {
@@ -569,11 +535,8 @@ my_strcasecmp (s1, s2)
 
 #if !HAVE_STRNCASECMP
 int
-my_strncasecmp (s1, s2, len)
-     const char *s1;
-     const char *s2;
-     int len;
-/*
+my_strncasecmp (const char *s1, const char *s2, int len)
+/*!
    Same as the ANSI C `strncmp()' function, but case insensitive.
 */
 {
@@ -604,7 +567,7 @@ my_strncasecmp (s1, s2, len)
 
 Bool
 get_actual_date ()
-/*
+/*!
    Gets the actual local/GMT date and time from the system resp.,
      evaluates the "actual" date from global `rc_adate'-ptr to string.
      Returns TRUE if it's possible to evaluate `rc_adate', otherwise FALSE.
@@ -895,10 +858,8 @@ get_actual_date ()
 
 
 int
-compare_d_m_name (string, mode)
-     const char *string;
-     const Cmode_enum mode;
-/*
+compare_d_m_name (const char *string, const Cmode_enum mode)
+/*!
    Compares the given day/month name `string' with built-in names and
      returns (1...7|1...12) either if `string' matches partly (until `\0'
      or first digit found in `string') or `string' matches complete.
@@ -980,10 +941,8 @@ compare_d_m_name (string, mode)
 
 
 int
-asc_sort (a, b)
-     const char **a;
-     const char **b;
-/*
+asc_sort (const char **a, const char **b)
+/*!
    The (q)sort compare function; ascending order.
 */
 {
@@ -993,10 +952,8 @@ asc_sort (a, b)
 
 
 int
-des_sort (a, b)
-     const char **a;
-     const char **b;
-/*
+des_sort (const char **a, const char **b)
+/*!
    The (q)sort compare function; descending order.
 */
 {
@@ -1006,10 +963,8 @@ des_sort (a, b)
 
 
 Bool
-is_presorted (table, elems)
-     char **table;
-     int elems;
-/*
+is_presorted (char **table, int elems)
+/*!
    Checks whether the textual entries in `&table[]' are presorted in
       ascending sort order.  Returns TRUE if the entries in `table'
       are presorted, otherwise FALSE.
@@ -1037,10 +992,8 @@ is_presorted (table, elems)
 
 
 void
-reverse_order (table, elems)
-     char **table;
-     const int elems;
-/*
+reverse_order (char **table, const int elems)
+/*!
    Rearranges (reverts) the sort order of the textual entries in
      `&table[]' from  ascending sort order to descending sort order
      by swapping the `table' pointers.
@@ -1067,9 +1020,8 @@ reverse_order (table, elems)
 
 
 const char *
-day_suffix (day)
-     int day;
-/*
+day_suffix (int day)
+/*!
    Returns the ordinal suffix (st, nd, rd or th) which is added to a single day number.
 */
 {
@@ -1113,9 +1065,8 @@ day_suffix (day)
 
 
 const char *
-short3_day_name (day)
-     const int day;
-/*
+short3_day_name (const int day)
+/*!
    Returns the short name of the day using the `printf()' format "%-3s".
 */
 {
@@ -1164,9 +1115,8 @@ short3_day_name (day)
 
 
 const char *
-short_day_name (day)
-     const int day;
-/*
+short_day_name (const int day)
+/*!
    Returns the short name of the day using the `printf()' format "%-2s".
 */
 {
@@ -1215,9 +1165,8 @@ short_day_name (day)
 
 
 const char *
-day_name (day)
-     const int day;
-/*
+day_name (const int day)
+/*!
    Returns the complete name of the day.
 */
 {
@@ -1233,9 +1182,8 @@ day_name (day)
 
 
 const char *
-short_month_name (month)
-     const int month;
-/*
+short_month_name (const int month)
+/*!
    Returns the short name of the month using the `printf()' format "%-3s".
 */
 {
@@ -1310,9 +1258,8 @@ short_month_name (month)
 
 
 const char *
-month_name (month)
-     const int month;
-/*
+month_name (const int month)
+/*!
    Returns the complete name of the month.
 */
 {
@@ -1353,7 +1300,7 @@ month_name (month)
 
 
 	  len = (int) strlen (s) - 1;
-	  mayname = (char *) my_malloc (len,
+	  mayname = (char *) my_malloc (len + 2,
 					ERR_NO_MEMORY_AVAILABLE,
 					__FILE__, ((long) __LINE__) - 2L,
 					"mayname", 0);
@@ -1373,11 +1320,8 @@ month_name (month)
 
 
 Ulint
-date2num (day, month, year)
-     const int day;
-     const int month;
-     const int year;
-/*
+date2num (const int day, const int month, const int year)
+/*!
    Returns the absolute number of days of the given date since
      00010101(==YYYYMMDD) respecting the missing period of the
      Gregorian Reformation.
@@ -1410,12 +1354,8 @@ date2num (day, month, year)
 
 
 void
-num2date (mjd, day, month, year)
-     Ulint mjd;
-     int *day;
-     int *month;
-     int *year;
-/*
+num2date (Ulint mjd, int *day, int *month, int *year)
+/*!
    Converts a delivered absolute number of days `mjd' to a standard
      date (since 00010101(==YYYYMMDD), returned in `&day', `&month' and `&year')
      respecting the missing period of the Gregorian Reformation.
@@ -1473,12 +1413,8 @@ num2date (mjd, day, month, year)
 
 
 Bool
-doy2date (doy, is_leap_year, day, month)
-     int doy;
-     const int is_leap_year;
-     int *day;
-     int *month;
-/*
+doy2date (int doy, const int is_leap_year, int *day, int *month)
+/*!
    Converts a given number of days of a year to a standard date
      (returned in `&day' and `&month') and returns:
        TRUE in case the `day_of_year' number is valid;
@@ -1529,11 +1465,8 @@ doy2date (doy, is_leap_year, day, month)
 
 
 int
-weekday_of_date (day, month, year)
-     const int day;
-     const int month;
-     const int year;
-/*
+weekday_of_date (const int day, const int month, const int year)
+/*!
    Returns the weekday of a Gregorian/Julian calendar date
      (month must be 1...12) and returns 1...7 (1==mo, 2==tu...7==su).
 */
@@ -1546,11 +1479,8 @@ weekday_of_date (day, month, year)
 
 
 int
-day_of_year (day, month, year)
-     const int day;
-     const int month;
-     const int year;
-/*
+day_of_year (const int day, const int month, const int year)
+/*!
    Returns the day of the year of a Gregorian or Julian calendar date
      (month must be 1...12) and returns 1...365|366.
 */
@@ -1569,9 +1499,8 @@ day_of_year (day, month, year)
 
 
 int
-days_of_february (year)
-     const int year;
-/*
+days_of_february (const int year)
+/*!
    Returns the number of days in February --- respecting the Gregorian
      Reformation period likewise the leap year rule as used by the
      Eastern Orthodox churches.
@@ -1607,11 +1536,8 @@ days_of_february (year)
 
 
 Bool
-valid_date (day, month, year)
-     const int day;
-     const int month;
-     const int year;
-/*
+valid_date (const int day, const int month, const int year)
+/*!
    Checks whether a delivered date is valid.
 */
 {
@@ -1629,11 +1555,8 @@ valid_date (day, month, year)
 
 
 Bool
-prev_date (day, month, year)
-     int *day;
-     int *month;
-     int *year;
-/*
+prev_date (int *day, int *month, int *year)
+/*!
    Sets a delivered date back by one day (to yesterday's date)
      respecting the missing period of the Gregorian Reformation.
      Returns FALSE in case a date was within the missing period
@@ -1674,11 +1597,8 @@ prev_date (day, month, year)
 
 
 Bool
-next_date (day, month, year)
-     int *day;
-     int *month;
-     int *year;
-/*
+next_date (int *day, int *month, int *year)
+/*!
    Sets the delivered date forwards by one day (to tomorrow's date)
      respecting the missing period of the Gregorian Reformation.
      Returns FALSE in case a date was in the missing period
@@ -1717,13 +1637,8 @@ next_date (day, month, year)
 
 
 int
-week_number (day, month, year, is_iso_week, start_day_of_week)
-     const int day;
-     const int month;
-     const int year;
-     const Bool is_iso_week;
-     const int start_day_of_week;
-/*
+week_number (const int day, const int month, const int year, const Bool is_iso_week, const int start_day_of_week)
+/*!
    Returns either a ISO-8601:1988 standard week number of the given date
      if the `is_iso_week' variable is TRUE, or a special value for marking
      a special event, which can be managed by the caller in a special way
@@ -1814,12 +1729,8 @@ week_number (day, month, year, is_iso_week, start_day_of_week)
 
 
 int
-weekno2doy (week, year, is_iso_week, start_day_of_week)
-     int week;
-     const int year;
-     const Bool is_iso_week;
-     const int start_day_of_week;
-/*
+weekno2doy (int week, const int year, const Bool is_iso_week, const int start_day_of_week)
+/*!
    Returns the "day_of_year" number of a Julian or Gregorian calendar year,
      the given week number (either ISO-8601:1988 or non-ISO) starts at.
      Week number may be:
@@ -1893,9 +1804,8 @@ weekno2doy (week, year, is_iso_week, start_day_of_week)
 
 
 int
-knuth_easter_formula (year)
-     const int year;
-/*
+knuth_easter_formula (const int year)
+/*!
    This procedure calculates the day and month of Easter giving the year.
    It returns the "actual day_of_year date" of Western Eastern (not the
    Eastern Easter of the Eastern Orthodox churches) after AD 463.
@@ -2006,11 +1916,8 @@ knuth_easter_formula (year)
 
 
 int
-julian_gregorian_diff (day, month, year)
-     const int day;
-     const int month;
-     const int year;
-/*
+julian_gregorian_diff (const int day, const int month, const int year)
+/*!
    Returns the day difference between the given Gregorian calendar date
      and the according Julian calendar date, i.e. the amount of days,
      the Julian calendar is past the Gregorian calendar.
@@ -2030,11 +1937,8 @@ julian_gregorian_diff (day, month, year)
 
 
 static void
-gregorian2julian (day, month, year)
-     int *day;
-     int *month;
-     int *year;
-/*
+gregorian2julian (int *day, int *month, int *year)
+/*!
    Converts a Gregorian date to a Julian date.
 */
 {
@@ -2082,13 +1986,8 @@ gregorian2julian (day, month, year)
 
 
 static int
-raw_week_number (day, month, year, is_iso_week, start_day_of_week)
-     const int day;
-     const int month;
-     const int year;
-     const Bool is_iso_week;
-     const int start_day_of_week;
-/*
+raw_week_number (const int day, const int month, const int year, const Bool is_iso_week, const int start_day_of_week)
+/*!
    Returns either the raw ISO-8601:1988 standard week number of the given
      date if the `is_iso_week' variable is TRUE.  Note that an ISO week
      starts on a Monday(=1) and ends on a Sunday(=7), and the first week
@@ -2164,9 +2063,8 @@ raw_week_number (day, month, year, is_iso_week, start_day_of_week)
 
 
 static const char *
-dflt_day_name (day)
-     const int day;
-/*
+dflt_day_name (const int day)
+/*!
    Returns the complete default (==English) name of the day
      (needed by the `compare_d_m_name()' function if another native language
      other than English must be supported).
@@ -2184,9 +2082,8 @@ dflt_day_name (day)
 
 
 static const char *
-dflt_month_name (month)
-     const int month;
-/*
+dflt_month_name (const int month)
+/*!
    Returns the complete default (==English) name of the month
      (needed by the `compare_d_m_name()' function if another native lanuage
      other than English must be supported).
